@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package App::Addex::Entry::EmailAddress;
+package App::Addex::Entry::EmailAddress 0.027;
 # ABSTRACT: an address book entry's email address
-$App::Addex::Entry::EmailAddress::VERSION = '0.026';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod An App::Addex::Entry::EmailAddress object represents, well, an addess for an
@@ -83,13 +83,24 @@ App::Addex::Entry::EmailAddress - an address book entry's email address
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
 An App::Addex::Entry::EmailAddress object represents, well, an addess for an
 entry.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -121,7 +132,7 @@ This method returns the address label, if any.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
