@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package App::Addex::Output;
+package App::Addex::Output 0.027;
 # ABSTRACT: base class for output plugins
-$App::Addex::Output::VERSION = '0.026';
+
 use Carp ();
 
 #pod =head1 DESCRIPTION
@@ -62,12 +62,23 @@ App::Addex::Output - base class for output plugins
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
 This is a base class for output plugins.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -92,7 +103,7 @@ This method is called after all entries have been processed.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
