@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package App::Addex::Output::Mutt;
+package App::Addex::Output::Mutt 0.027;
 # ABSTRACT: generate mutt configuration from an address book
-$App::Addex::Output::Mutt::VERSION = '0.026';
+
 use parent qw(App::Addex::Output::ToFile);
 
 use Text::Unidecode ();
@@ -137,7 +137,7 @@ App::Addex::Output::Mutt - generate mutt configuration from an address book
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
@@ -153,6 +153,17 @@ to that folder and a mailboxes line is created for the folder.  If the entry
 has a "sig" value, a send-hook is created to use that signature when composing
 a message to the entry.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 process_entry
@@ -172,7 +183,7 @@ The valid configuration parameters for this plugin are:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
