@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package App::Addex::Output::Procmail;
+package App::Addex::Output::Procmail 0.027;
 # ABSTRACT: generate procmail recipes from an address book
-$App::Addex::Output::Procmail::VERSION = '0.026';
+
 use parent qw(App::Addex::Output::ToFile);
 
 #pod =head1 DESCRIPTION
@@ -62,7 +62,7 @@ App::Addex::Output::Procmail - generate procmail recipes from an address book
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
@@ -73,6 +73,17 @@ its addresses to the given folder.
 Forward slashes in the folder name are converted to dots, showing my bias
 toward Courier IMAP.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 process_entry
@@ -89,7 +100,7 @@ The valid configuration parameters for this plugin are:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
