@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package App::Addex::Output::ToFile;
+package App::Addex::Output::ToFile 0.027;
 # ABSTRACT: base class for output plugins that write to files
-$App::Addex::Output::ToFile::VERSION = '0.026';
+
 use parent 'App::Addex::Output';
 
 use Carp ();
@@ -79,7 +79,7 @@ App::Addex::Output::ToFile - base class for output plugins that write to files
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
@@ -87,6 +87,17 @@ This is a base class for output plugins that will write to files.  The
 "filename" configuration parameter must be given, and must be the name of a
 file to which the user can write.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -108,7 +119,7 @@ This method appends the given string to the output file, adding a newline.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
