@@ -3,6 +3,8 @@ use strict;
 use warnings;
 
 package App::Addex::Output::Callback;
+use App::Addex::Output;
+BEGIN { our @ISA = 'App::Addex::Output' }
 
 sub new {
   my ($self, $arg) = @_;
